==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebActivePaneEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActivePaneEventArgsDescription } from "./WebActivePaneEventArgsDescription";
/**
 * @hidden
 */
var WebActivePaneEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActivePaneEventArgsDescriptionMetadata, _super);
    function WebActivePaneEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActivePaneEventArgsDescriptionMetadata.b = function (a) {
        if (WebActivePaneEventArgsDescriptionMetadata.a == null) {
            WebActivePaneEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActivePaneEventArgsDescriptionMetadata.c(WebActivePaneEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebActivePaneEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebActivePaneEventArgsDescriptionMetadata.a);
        WebActivePaneEventArgsDescriptionMetadata.d(a);
    };
    WebActivePaneEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActivePaneEventArgs");
        a.item("Detail", "ExportedType:WebActivePaneEventArgs");
    };
    WebActivePaneEventArgsDescriptionMetadata.d = function (a) {
        WebActivePaneEventArgsDescriptionMetadata.b(a);
        a.u("WebActivePaneEventArgs", function () { return new WebActivePaneEventArgsDescription(); });
        a.t("WebActivePaneEventArgs", WebActivePaneEventArgsDescriptionMetadata.a);
    };
    WebActivePaneEventArgsDescriptionMetadata.$t = markType(WebActivePaneEventArgsDescriptionMetadata, 'WebActivePaneEventArgsDescriptionMetadata');
    WebActivePaneEventArgsDescriptionMetadata.a = null;
    return WebActivePaneEventArgsDescriptionMetadata;
}(Base));
export { WebActivePaneEventArgsDescriptionMetadata };

==> igniteui-react-core-18.0.0.tgz: package/esm5/lib/WebActivePaneEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebActivePaneEventArgsDescription } from "./WebActivePaneEventArgsDescription";
/**
 * @hidden
 */
var WebActivePaneEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActivePaneEventArgsDescriptionMetadata, _super);
    function WebActivePaneEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActivePaneEventArgsDescriptionMetadata.b = function (a) {
        if (WebActivePaneEventArgsDescriptionMetadata.a == null) {
            WebActivePaneEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActivePaneEventArgsDescriptionMetadata.c(WebActivePaneEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebActivePaneEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebActivePaneEventArgsDescriptionMetadata.a);
        WebContentPaneDescriptionMetadata.d(a);
    };
    WebActivePaneEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActivePaneEventArgs");
        a.item("NewPane", "ExportedType:WebContentPane");
        a.item("OldPane", "ExportedType:WebContentPane");
    };
    WebActivePaneEventArgsDescriptionMetadata.d = function (a) {
        WebActivePaneEventArgsDescriptionMetadata.b(a);
        a.u("WebActivePaneEventArgs", function () { return new WebActivePaneEventArgsDescription(); });
        a.t("WebActivePaneEventArgs", WebActivePaneEventArgsDescriptionMetadata.a);
    };
    WebActivePaneEventArgsDescriptionMetadata.$t = markType(WebActivePaneEventArgsDescriptionMetadata, 'WebActivePaneEventArgsDescriptionMetadata');
    WebActivePaneEventArgsDescriptionMetadata.a = null;
    return WebActivePaneEventArgsDescriptionMetadata;
}(Base));
export { WebActivePaneEventArgsDescriptionMetadata };
